@@ -1,4 +1,4 @@
-from n3.builder import *
+from n3 import *
 
 
 class ImageClassification(Trainer):
