@@ -1,10 +1,10 @@
 import torch.optim as optim
 
-from n3.builder import OptimNode
+from n3 import OptimNode
 
 
 class Adam(OptimNode):
     learning_rate: float
 
-    def _initialize(self, params):
+    def initialize(self, params):
         return optim.Adam(params, lr=self.learning_rate)
